@@ -1,4 +1,4 @@
-/* gfloppy->c
+/* gfloppy.c
  *
  * Copyright (C) 1999 Red Hat, Inc.
  *
@@ -18,6 +18,8 @@
  * USA
  */
 
+#include "config.h"
+
 #include <glib.h>
 
 #include <stdio.h>
@@ -28,8 +30,11 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <linux/major.h>
+
+#ifdef HAVE_LINUX_FD_H
 #include <linux/fd.h>
 #include <linux/fs.h>
+#endif
 
 
 #include "gfloppy.h"
@@ -146,7 +151,7 @@ static int
 format_ext2fs (GFloppy *floppy)
 {
 	gchar *cmd;
-	gint rc = 0;
+	gint rc = 0, i;
 	fd_print (floppy, "P000");
 
 	/* low-level format */
@@ -158,12 +163,14 @@ format_ext2fs (GFloppy *floppy)
 
 	/* make the filesystem */
 	cmd = make_mke2fs_cmd (floppy);
+
 	fd_print (floppy, "MMaking filesystem on disk...");
 	rc = system (cmd);
 	if (rc > 3) {
 		fd_print (floppy, "EUnable to create filesystem correctly.");
 		return rc;
 	}
+
 	fd_print (floppy, "MMaking filesystem on disk... Done");
 	if (floppy->quick_format)
 		fd_print (floppy, "P100");
